import argparse, os, shutil

from pathlib import Path
from .cute_python import snek

FILE_NAME = 'settings_local.py'


def main():
    print(snek)

    parser = argparse.ArgumentParser(description='Create Django Local Settings')
    parser.add_argument('-p', metavar='PATH', help='Django Project Application Path')
    parser.add_argument('-f', action='store_true', help='Show Django Local Settings Format')
    args = parser.parse_args()

    WORKING_DIR = Path(args.p or os.getcwd())
    PACKAGE_DIR = Path(__file__).resolve(strict=True).parent

    GIT_IGNORE = WORKING_DIR.parent/'.gitignore'
    DJANGO_SETTINGS = WORKING_DIR/'settings.py'

    if args.f:
        with open(PACKAGE_DIR/FILE_NAME, 'r') as fb:
            print(fb.read())
    elif os.path.isfile(WORKING_DIR/FILE_NAME):
        print(f"{FILE_NAME} is already there at {WORKING_DIR}")
    else:
        shutil.copyfile(PACKAGE_DIR/FILE_NAME, WORKING_DIR/FILE_NAME)
        if os.path.isfile(GIT_IGNORE):
            fp = open(GIT_IGNORE, 'a')
        else:
            fp = open(GIT_IGNORE, 'w')
        fp.write('\n# Added by `dsl` (Django Setting Local) \nsettings_local*\n')
        fp.close()

        fp = open(DJANGO_SETTINGS, 'a')
        fp.write("\n\n\n\n")
        fp.write("\n##################### END OF SETTINGS ################################")
        fp.write("\nfrom django_settings_local import import_local;import_local(globals())")
        fp.write("\n##################### END OF SETTINGS ################################")
        fp.close()

if __name__ == '__main__':
    main()



import importlib, os

from pathlib import Path
from .cute_python import snek

DSL_CACHE = os.environ.get("DSL_CACHE")

def pritty_print(msg):
    print('\n','#'*len(msg),'\n',msg,'\n','#'*len(msg))

def import_local(g):
    PROJECT_APP = Path(g['__file__']).resolve(strict=True).parent.name
    try:
        msg = "Django local settings applied"
        settings_local = importlib.import_module(".settings_local", PROJECT_APP)
        for flag in dir(settings_local):
            if flag.startswith("__"):
                continue
            g.update(flag=getattr(settings_local, flag))
        settings_local.patch_globals(g)
    except ImportError:
        msg = "Use `settings_local.py` in the project app to override global settings"
    except AttributeError:
        msg = "For global settings mutation, see format of settings_local.py `dsl -f`"
    finally:
        if not DSL_CACHE:
            print(snek)
            pritty_print(msg)
        os.environ.setdefault("DSL_CACHE", "PRINTED")



DEBUG = True
ALLOWED_HOSTS = ['*']


def patch_globals(g):
    ''' Patch global settings in case you don't
    want to override the whole complex settings object.
    Examples:

    g['DATABASES']['default']['HOST'] = 'localhost'
    g['INSTALLED_APPS'] += ('debug_toolbar',)
    g['MIDDLEWARE'] += ('debug_toolbar.middleware.DebugToolbarMiddleware',)
    '''



from setuptools import setup

setup(
  name = 'django-settings-local',
  packages = ['django_settings_local'],
  version = '0.1.4',
  description = 'Manage Django Local Settings',
  author = 'Fasih Ahmad Fakhri',
  author_email = 'fasih@email.com',
  url = 'https://github.com/fasih/django-settings-local',
  download_url='https://github.com/fasih/django-settings-local/archive/0.1.4.tar.gz',
  keywords = 'django local settings',
  entry_points={
    'console_scripts': [
      'dsl = django_settings_local.__main__:main',
    ],
  },
  license='GPL-3.0',
  classifiers=[
        'License :: OSI Approved :: GNU General Public License v3 (GPLv3)',
        'Framework :: Django',
        'Development Status :: 5 - Production/Stable',
        'Intended Audience :: Developers',
        'Programming Language :: Python :: 3',
        'Topic :: Software Development :: Libraries'
    ],
    python_requires='>=3.6',
)
